Lua_ChaosForestRankWindow = class("Lua_ChaosForestRankWindow", Lua_Window);
function Lua_ChaosForestRankWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.MAIN_MENU_TOP_LAYER;
	self.windowName = "Lua_ChaosForestRankWindow";
	self.skinName = "ChaosForestRankWindow_skin"
	self.showBlackMask = true;
	self.isFullSizeWin = true;
end

function Lua_ChaosForestRankWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.bg_2:SetDimensions(720, 583 + self.adaptHeight);
	self.text_3:setLangValue(340030);

	local posDic = {{0, -154}, {-252, -188}, {252, -187.5}};
	self.modelArr = Array();
	local item;
	for i = 1, 3 do
		item = Lua_ChaosForestRankModelItem.new(self.content);
		item:setRectAnchor(1);
		item:setLocation(posDic[i][1], posDic[i][2], 0);
		item:setRank(i);
		item:setData(nil);
		self.modelArr:add(item);
	end

	self.itemList = Lua_DragList.new(self.content, 687, 550 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -160, 0);
	self.itemList:setListCell(Lua_ChaosForestRankItem, 687, 123, 1);
	self.itemList:setCellSpacing(0, 10);

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setRectAnchor(7);
	self.avatarItem:setScale(0.8, 0.8, 1);
	self.avatarItem:setLocation(-165, 189, 0);

	self:createBackBtn();
	self.checkReward:addClickFuntion(self, self.onCheckReward);
	self.checkHurt:addClickFuntion(self, self.onCheckHurt);

	self:addLuaEvent("CHAOSFOREST_RANK_UPDATE", self, self.updateServerInfo);
	Lua_ProxyManager.getProxy("Lua_ChaosForestProxy"):sRankInfo();
end

function Lua_ChaosForestRankWindow:dispose()
	Lua_ProxyManager.getProxy("Lua_ChaosForestProxy"):sWinInfo(); -- 策划要求
	if self.modelArr ~= nil then
		self.modelArr:dispose();
		self.modelArr:clear();
		self.modelArr = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	self:superCall("dispose");
end

function Lua_ChaosForestRankWindow:onScreenResize()
	self:superCall("onScreenResize");
	self.bg_2:SetDimensions(720, 583 + self.adaptHeight);
	self.itemList:setContentRect(687, 550 + self.adaptHeight);
end

function Lua_ChaosForestRankWindow:updateServerInfo(msg)
	if msg == nil then
		return;
	end

	local list = msg.head_rank_list;
	if list ~= nil and self.modelArr ~= nil then
		for i = 1, self.modelArr:getSize() do
			if #list > i - 1 then
				self.modelArr[i]:setData(list[i]);
			else
				self.modelArr[i]:setData(nil);
			end
		end
	end

	list = msg.other_rank_list;
	if list == nil or #list <= 0 then
		self.itemList:setEnable(false);
		self:showNone(true);
	else
		self.itemList:setEnable(true);
		self.itemList:setArrayData(list);
		self:showNone(false);
	end

	self:updateSelf(msg.self_rank);
end

function Lua_ChaosForestRankWindow:showNone(bShow)
	if bShow then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "ui_liaotian_widget_002", 0, -156, 648, 119);
		end
		self.noneIcon:setEnable(true);

		if self.noneText == nil then
			self.noneText = UICreate.createLabel(self.content, LanUtil.getValue(340026), 0, -156, 100, 40, 34);
			self.noneText.pivot = UIUtils.Pivot.Center;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("EBEBEB");
		end
		self.noneText:setEnable(true);
	else
		if self.noneIcon ~= nil then
			self.noneIcon:setEnable(false);
		end
		if self.noneText ~= nil then
			self.noneText:setEnable(false);
		end
	end
end

function Lua_ChaosForestRankWindow:updateSelf(data)
	self.data = data;
	if data.rank <= 0 then
		self.rankIcon:setEnable(true);
		if self.rankNum ~= nil then
			self.rankNum:setEnable(false);
		end
	else
		self.rankIcon:setEnable(false);
		if self.rankNum == nil then
			self.rankNum = Lua_NumberImage.new(self.content);
			self.rankNum:setRectAnchor(7);
			self.rankNum:setLocation(-280, 189, 0);
			self.rankNum.numOffsetX = -4;
			self.rankNum.numAtlas = "number";
			self.rankNum.preStr = "ui_djc2_title_0";
		end
		self.rankNum:setEnable(true);
		self.rankNum.num = data.rank;
	end

	self.avatarItem:setRoleId(data.player_show.id);
	self.avatarItem:setRoleDressUp(data.player_show.dress_info);
	self.avatarItem:setRoleLevel(data.player_show.level);

	self.nameText.text = data.player_show.name;
	self.hurtText.text = data.value;

	if data.hurt_collect == nil or data.hurt_collect.attacker == nil or tonumber(data.hurt_collect.attacker.id) <= 0 or data.hurt_collect.defender == nil or tonumber(data.hurt_collect.defender.id) <= 0 then
		self.checkHurt:setEnable(false);
	else
		self.checkHurt:setEnable(true);
	end
end

function Lua_ChaosForestRankWindow:onCheckReward(go)
	Lua_WindowUtil.openWin("Lua_ChaosForestRankRewardWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_ChaosForestRankWindow:onCheckHurt(GO)
	if self.data == nil then
		return;
	end
	Lua_WindowUtil.openWin("Lua_FightOverallHurtWindow", Lua_WinParam.ACTION_OPEN, self.data.hurt_collect);
end




















Lua_ChaosForestRankModelItem = class("Lua_ChaosForestRankModelItem", Lua_DisplayObject);
function Lua_ChaosForestRankModelItem:ctor(p)
	self:superCall("ctor", p, "ChaosForestRankModelItem_skin");
end

function Lua_ChaosForestRankModelItem:buildShowItem()
	self:superCall("buildShowItem");
	self.checkHurt:addClickFuntion(self, self.onCheckHurt);
end

function Lua_ChaosForestRankModelItem:dispose()
	if self.modelEffImg then
		self.modelEffImg:dispose()
		self.modelEffImg = nil
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChaosForestRankModelItem:setRank(rank)
	self.rank = rank
	self.rankIcon:setAltas("common_altas_3", "ui_djc_label_0"..rank);
	if rank == 1 then
		self.rankIcon:setLocation(-81, -70, 0);
		self.hurtBg:setLocation(0, -320, 0);
		self.hurtText:setLocation(3.5, -319, 0);
		self.checkHurt:setLocation(100, -320, 0);
	elseif rank == 2 then
		self.rankIcon:setLocation(-78, -107, 0);
		self.hurtBg:setLocation(4, -307, 0);
		self.hurtText:setLocation(3, -305.5, 0);
		self.checkHurt:setLocation(103, -307, 0);
	else
		self.rankIcon:setLocation(-71, -62, 0);
		self.hurtBg:setLocation(-7.5, -297.5, 0);
		self.hurtText:setLocation(-8, -296, 0);
		self.checkHurt:setLocation(90.5, -297.5, 0);
	end
end

function Lua_ChaosForestRankModelItem:setData(data)
	self.data = data;
	if data == nil then
		self.nameText:setLangValue(340018);
		self.hurtText.text = "";
		if self.modelEffImg then
			self.modelEffImg:setEnable(false)
		end
	else
		self.nameText.text = data.player_show.name;
		self.hurtText.text = data.value;
		if self.modelEffImg == nil then
			local vo = DataCenter.roleData:getDressUpId(Lua_DressUpDefine.MAINTYPE_MODEL, data.player_show.dress_info);
			vo = DataCenter.roleUtil:getDressUpVoById(vo);
			self.modelEffImg = UICreate.createModelEffImg(self.content, vo.modelUrl, vo.modelSrc, 0, -140, 0, 0);
			self.modelEffImg.siblingIndex = 0
			self.modelEffImg:setCamField(1, 1, 100, true)
			self.modelEffImg:setCamPos(0, 1, -10)
			self.modelEffImg:setModelEffDir(180)
			self.modelEffImg.canRot = false
			self.modelEffImg.clickScale = false
			self.modelEffImg:addClickFuntion(self, self.onModelClick)
		end
		self.modelEffImg:setEnable(true)
		self.modelEffImg:setScale(0.35, 0.35, 0.35)
	end

	if data == nil or data.hurt_collect == nil or data.hurt_collect.attacker == nil or tonumber(data.hurt_collect.attacker.id) <= 0 or data.hurt_collect.defender == nil or tonumber(data.hurt_collect.defender.id) <= 0 then
		self.checkHurt:setEnable(false);
	else
		self.checkHurt:setEnable(true);
	end
end

function Lua_ChaosForestRankModelItem:onCheckHurt(GO)
	if self.data == nil then
		return;
	end
	Lua_WindowUtil.openWin("Lua_FightOverallHurtWindow", Lua_WinParam.ACTION_OPEN, self.data.hurt_collect);
end

function Lua_ChaosForestRankModelItem:onModelClick(go)
	if self.data == nil then
		return;
	end

	if DataCenter.roleData:isMyself(self.data.player_show.id) then
		OperateAlert.showLangValue(171025);
	else
		Lua_WindowUtil.openWin("Lua_PlayerInfoWindow", Lua_WinParam.ACTION_OPEN, self.data.player_show.id);
	end	
end






















Lua_ChaosForestRankItem = class("Lua_ChaosForestRankItem", Lua_ListCell);
function Lua_ChaosForestRankItem:ctor(p)
	self:superCall("ctor", p, "ChaosForestRankItem_skin");
end

function Lua_ChaosForestRankItem:buildShowItem()
	self:superCall("buildShowItem");

	self.rankNum = Lua_NumberImage.new(self.content);
	self.rankNum:setLocation(-280, 0, 0);
	self.rankNum.numOffsetX = -4;
	self.rankNum.numAtlas = "number";
	self.rankNum.preStr = "ui_djc_title_0";

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setScale(0.9, 0.9, 1);
	self.avatarItem:setLocation(-165, 0, 0);

	self.checkHurt:setEnable(false);
	self.checkHurt:addClickFuntion(self, self.onCheckHurt);
end

function Lua_ChaosForestRankItem:dispose()
	if self.rankNum ~= nil then
		self.rankNum:dispose();
		self.rankNum = nil;
	end
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChaosForestRankItem:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	self.avatarItem:setRoleId(data.player_show.id);
	self.avatarItem:setRoleDressUp(data.player_show.dress_info);
	self.avatarItem:setRoleLevel(data.player_show.level);

	self.rankNum.num = data.rank;
	self.nameText.text = data.player_show.name;
	self.hurtText.text = data.value;

	if data.hurt_collect == nil or data.hurt_collect.attacker == nil or tonumber(data.hurt_collect.attacker.id) <= 0 or data.hurt_collect.defender == nil or tonumber(data.hurt_collect.defender.id) <= 0 then
		self.checkHurt:setEnable(false);
	else
		self.checkHurt:setEnable(true);
	end
end

function Lua_ChaosForestRankItem:onCheckHurt(go)
	if self.data == nil then
		return;
	end
	Lua_WindowUtil.openWin("Lua_FightOverallHurtWindow", Lua_WinParam.ACTION_OPEN, self.data.hurt_collect);
end