-- 伤害奖励
Lua_ChaosForestRecordWindow = class("Lua_ChaosForestRecordWindow", Lua_Window);
function Lua_ChaosForestRecordWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_ChaosForestRecordWindow";
	self.skinName = "ChaosForestRecordWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_ChaosForestRecordWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.itemList = Lua_DragList.new(self.content, 625, 560, Lua_AxisDefine.Vertical);
	self.itemList:setLocation(0, -110, 0);
	self.itemList:setListCell(Lua_ChaosForestRecordItem, 625, 180, 1);
	
	self:updateShowInfo();
	self:addLuaEvent("CHAOSFOREST_RECORD_UPDATE", self, self.updateServerInfo);
	Lua_ProxyManager.getProxy("Lua_ChaosForestProxy"):sRecordInfo();
end

function Lua_ChaosForestRecordWindow:dispose()
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.attrArr ~= nil then
		self.attrArr:dispose();
		self.attrArr:clear();
		self.attrArr = nil;
	end
	self:superCall("dispose");
end

function Lua_ChaosForestRecordWindow:updateShowInfo()
	local arr = self:getRecordArr();
	self.itemList:setArrayData(arr);
end

function Lua_ChaosForestRecordWindow:getRecordArr()
	local data = DataCenter.chaosForestData;
	local max_level = DataCenter.chaosForestUtil:getConstConfig("max_level", 1, 10);
	local arr = Array();
	local id;
	local info;
	local config;
	local sortWeight;
	for i = 1, max_level - 1 do
		id = data.round * 1000 + i;
		info = DataCenter.chaosForestData:getRecordInfo(id);
		config = DataCenter.chaosForestUtil:getLevelConfig(id);
		if info == nil then
			sortWeight = -config.level_up_hurt;
		else
			sortWeight = config.level_up_hurt;
		end
		arr:add({ id = id, sortWeight = sortWeight });
	end
	arr:sort("sortWeight", true);
	return arr;
end

function Lua_ChaosForestRecordWindow:updateServerInfo()
	local bossId = DataCenter.chaosForestData.recordBoss;
	local config = DataCenter.chaosForestUtil:getLevelConfig(bossId);
	local arr = DataCenter.attributesUtil:getAttrArrByDic(config);
	local dataLen = arr:getSize();
	if self.attrArr == nil then
		self.attrArr = Array();
	end
	local len = self.attrArr:getSize();
	local maxLen = dataLen > len and dataLen or len;
	local item;
	for i = 1, maxLen do
		item = self.attrArr[i];
		if i > dataLen then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_ChaosForestRecordAttrItem.new(self.content);
				self.attrArr:add(item);
			else
				item:setEnable(true);
			end
			item:setLocation(-180 + (i - 1) * 180, 273, 0);
			item:setData(arr[i]);
		end
	end

	bossId = DataCenter.chaosForestData.recordMaxBoss;
	if bossId == nil or bossId <= 0 then
		self.nameText.text = Lua_ColorDefine.getColorStr("9C8472", LanUtil.getValue(340018));
		self.desText.text = LanUtil.formateStr(340019, config.name);
	else
		local serverInfo = DataCenter.chaosForestData:getRecordInfo(bossId);
		self.nameText.text = LanUtil.formateStr(340024, serverInfo.player.name);
		self.desText.text = LanUtil.formateStr(340020, serverInfo.player.name, tostring(config.level), config.name);
	end

	arr = self:getRecordArr();
	self.itemList:setArrayData(arr);
end




















Lua_ChaosForestRecordItem = class("Lua_ChaosForestRecordItem", Lua_ListCell);
function Lua_ChaosForestRecordItem:ctor(p)
	self:superCall("ctor", p, "ChaosForestRecordItem_skin");
end

function Lua_ChaosForestRecordItem:buildShowItem()
	self:superCall("buildShowItem");

	self.avatarItem = Lua_AvatarItem.new(self.content);
	self.avatarItem:setLocation(-250, -19, 0);

	self.itemList = Lua_ItemIconList.new(self.content);
	self.itemList:setLocation(50, -19, 0);
	self.itemList.pivot = 0;

	self.btnReceive:addClickFuntion(self, self.onBtnReceiveClick);
end

function Lua_ChaosForestRecordItem:dispose()
	if self.avatarItem ~= nil then
		self.avatarItem:dispose();
		self.avatarItem = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ChaosForestRecordItem:setData(data)
	self.data = data;
	local config = DataCenter.chaosForestUtil:getLevelConfig(data.id);
	if config == nil then
		return;
	end

	self.title.text = LanUtil.formateStr(340021, numberTrans(config.level_up_hurt));
	self.level.text = LanUtil.formateStr(340022, config.name, config.level_str);--tostring(config.level + 1));
	self.itemList:setArrayData(config.level_up_reward);

	self.avatarItem:init();
	local serverInfo = DataCenter.chaosForestData:getRecordInfo(data.id);
	if serverInfo == nil then
		self.noneText:setEnable(true);
		self.name.text = "";
		self.time.text = "";
		self.signIcon:setEnable(false);
		self.btnReceive:setEnable(false);
		self.stateIcon:setEnable(true);
		self.stateIcon:setAltas("common_altas_2", "ui_common_label_27");
		self:showRedDot(false);

		self.avatarItem:setScale(0.75, 0.75, 1);
		self.avatarItem:setRoleId(nil);
		self.avatarItem:setAvatarBg(nil, nil);
		self.avatarItem:setAvatar("chaos_forest_altas", "ui_hdsl_label_07");
		self.avatarItem:setRoleFrame(nil);
	else
		self.noneText:setEnable(false);
		self.name.text = serverInfo.player.name;
		self.time.text = LanUtil.formateStr(340023, os.date("%Y.%m.%d", serverInfo.time));
		self.signIcon:setEnable(true);
		if serverInfo.reward_state == 2 then
			self.btnReceive:setEnable(false);
			self.stateIcon:setEnable(true);
			self.stateIcon:setAltas("common_altas_1", "ui_common_label_17");
			self:showRedDot(false);
		elseif serverInfo.reward_state == 1 then
			self.btnReceive:setEnable(true);
			self.stateIcon:setEnable(false);
			self:showRedDot(true);
		else
			self.btnReceive:setEnable(false);
			self.stateIcon:setEnable(true);
			self.stateIcon:setAltas("common_altas_2", "ui_common_label_27");
			self:showRedDot(false);
		end

		self.avatarItem:setScale(0.7, 0.7, 1);
		self.avatarItem:setRoleId(serverInfo.player.id);
		self.avatarItem:setRoleDressUp(serverInfo.player.dress_info);
	end
end

function Lua_ChaosForestRecordItem:showRedDot(bShow)
	if bShow == true then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(265, 0, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint ~= nil then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_ChaosForestRecordItem:onBtnReceiveClick(go)
	if self.data == nil then
		return;
	end
	Lua_ProxyManager.getProxy("Lua_ChaosForestProxy"):sReceiveRecordReward(self.data.id);
end

function Lua_ChaosForestRecordItem:onPressClick()
	self.itemList:onBoundClick();
end




















Lua_ChaosForestRecordAttrItem = class("Lua_ChaosForestRecordAttrItem", Lua_DisplayObject);
function Lua_ChaosForestRecordAttrItem:ctor(p)
    self:superCall("ctor", p);
end

function Lua_ChaosForestRecordAttrItem:buildShowItem()
	self:superCall("buildShowItem");

	self.attr_icon = UICreate.createUIAtlasImage(self.content, nil, nil, 0, 0, 0, 0);
	self.attr_icon.pivot = Lua_WindowUtil.getPivot(3);

	self.attr_text = UICreate.createLabel(self.content, nil, 32, 0, 100, 31, 22);
	self.attr_text.pivot = Lua_WindowUtil.getPivot(3);
	self.attr_text.alignmentValue = 3;
	self.attr_text.horizontalOverflowValue = 1;
end

function Lua_ChaosForestRecordAttrItem:dispose()
	self:superCall("dispose");
end

function Lua_ChaosForestRecordAttrItem:setData(attrVo)
	self.attr_icon:setAltas("common_altas_2", attrVo.attr_icon_2);
	self.attr_text.text = spliceStr("<color=#9C8472>", attrVo.show_name, "</color>", "<color=#459252>+", attrVo.value, "</color>");
end